@@ -7,10 +7,10 @@ def cmd():
 
 
 @cmd.command()
-@click.argument('keyfile')
-@click.argument('file_path')
-def encrypt(keyfile, file_path):
-    encrypt_file(file_path, keyfile)
+@click.option('--key', default=None, help="encrypt key string")
+@click.option('--file', default=None, help="file to be encrypt")
+def encrypt(key, file):
+    encrypt_file(file, key)
     click.echo('encrypted!')
 
 
